@@ -1,7 +1,8 @@
 """Functions for dealing with comic cover thumbnails."""
 
-from codex.librarian.covers.create import CoverCreateMixin
-from codex.librarian.covers.purge import CoverPurgeMixin
+from typing_extensions import override
+
+from codex.librarian.covers.purge import CoverPurgeThread
 from codex.librarian.covers.tasks import (
     CoverCreateAllTask,
     CoverRemoveAllTask,
@@ -11,18 +12,19 @@ from codex.librarian.covers.tasks import (
 )
 
 
-class CoverContributorThread(CoverCreateMixin, CoverPurgeMixin):
+class CoverThread(CoverPurgeThread):
     """Create comic covers in it's own thread."""
 
+    @override
     def process_item(self, item):
-        """Run the contributor."""
+        """Run the task method."""
         task = item
         if isinstance(task, CoverSaveToCache):
             self.save_cover_to_cache(task.cover_path, task.data)
         elif isinstance(task, CoverRemoveAllTask):
             self.purge_all_comic_covers(self.librarian_queue)
         elif isinstance(task, CoverRemoveTask):
-            self.purge_comic_covers(task.comic_pks)
+            self.purge_comic_covers(task.pks, custom=task.custom)
         elif isinstance(task, CoverRemoveOrphansTask):
             self.cleanup_orphan_covers()
         elif isinstance(task, CoverCreateAllTask):
