@@ -1,11 +1,12 @@
 """Covers Tasks."""
 
+from abc import ABC
 from dataclasses import dataclass
 
 
 @dataclass
-class CoverTask:
-    """Handle with the CoverContributor."""
+class CoverTask(ABC):  # noqa: B024
+    """Handle with the CoverThread."""
 
 
 @dataclass
@@ -18,18 +19,12 @@ class CoverRemoveOrphansTask(CoverTask):
     """Clean up covers from missing comics."""
 
 
-@dataclass
-class LibrariesTask:
-    """Tasks over a set of libraries."""
-
-    library_ids: frozenset
-
-
 @dataclass
 class CoverRemoveTask(CoverTask):
     """Purge a set of comic covers."""
 
-    comic_pks: frozenset
+    pks: frozenset
+    custom: bool
 
 
 @dataclass
