@@ -2,10 +2,12 @@
 
 from datetime import datetime, timezone
 from tarfile import TarError
+from types import MappingProxyType
 from zipfile import BadZipFile, LargeZipFile
 
 from comicbox.box import Comicbox
 from comicbox.exceptions import UnsupportedArchiveTypeError
+from comicbox.schemas.comicbox import PAGE_COUNT_KEY
 from py7zr.exceptions import ArchiveError as Py7zError
 from rarfile import Error as RarError
 
@@ -24,15 +26,18 @@ class ExtractMetadataImporter(AggregateMetadataImporter):
     """Aggregate metadata from comics to prepare for importing."""
 
     @staticmethod
-    def _metadata_mtime(path: str) -> datetime | None:
-        try:
-            comic = Comic.objects.get(path=path)
-        except Comic.DoesNotExist:
-            return None
-        mtime = comic.metadata_mtime
-        if mtime and (mtime.tzinfo is None or mtime.tzinfo.utcoffset(mtime) is None):
-            mtime = mtime.replace(tzinfo=timezone.utc)
-        return mtime
+    def _old_comic_values(
+        old_comic_values: MappingProxyType, path: str
+    ) -> tuple[str | None, int | None, datetime | None]:
+        old_comic = old_comic_values.get(path, {})
+        old_file_type = old_comic.get("file_type")
+        old_page_count = old_comic.get(PAGE_COUNT_KEY)
+        old_mtime = old_comic.get("metadata_mtime")
+        if old_mtime and (
+            old_mtime.tzinfo is None or old_mtime.tzinfo.utcoffset(old_mtime) is None
+        ):
+            old_mtime = old_mtime.replace(tzinfo=timezone.utc)
+        return old_file_type, old_page_count, old_mtime
 
     def _set_import_metadata_flag(self):
         """Set import_metadata flag."""
@@ -45,29 +50,54 @@ class ExtractMetadataImporter(AggregateMetadataImporter):
             self.log.warning("Admin flag set to NOT import metadata.")
         return import_metadata
 
-    def _extract_path(self, path: str, *, import_metadata: bool):
+    def _extract_path_comicbox(
+        self,
+        path: str,
+        old_comic_values: MappingProxyType,
+        *,
+        import_metadata: bool,
+    ):
+        old_file_type, old_page_count, old_mtime = self._old_comic_values(
+            old_comic_values, path
+        )
+        md = {}
+        with Comicbox(path, config=COMICBOX_CONFIG, logger=self.log) as cb:
+            if import_metadata:
+                new_md_mtime = cb.get_metadata_mtime()
+                if (
+                    not self.task.check_metadata_mtime
+                    or not new_md_mtime
+                    or not old_mtime
+                    or (new_md_mtime > old_mtime)
+                ):
+                    md = cb.to_dict()
+                    md = md.get("comicbox", {})
+                    md["metadata_mtime"] = new_md_mtime
+                else:
+                    md["page_count"] = cb.get_page_count()
+            else:
+                md["page_count"] = cb.get_page_count()
+            file_type = cb.get_file_type()
+
+        if old_page_count == md.get("page_count"):
+            md.pop("page_count")
+        if old_file_type != file_type:
+            md["file_type"] = file_type
+
+        if md:
+            md["path"] = path
+        return md
+
+    def _extract_path(
+        self, path: str, old_comic_values: MappingProxyType, *, import_metadata: bool
+    ):
         """Extract metadata from comic and clean it for codex."""
         md = {}
         failed_import = {}
         try:
-            with Comicbox(path, config=COMICBOX_CONFIG, logger=self.log) as cb:
-                if import_metadata:
-                    new_md_mtime = cb.get_metadata_mtime()
-                    if (
-                        not self.task.check_metadata_mtime
-                        or not new_md_mtime
-                        or not (old_md_mtime := self._metadata_mtime(path))
-                        or (new_md_mtime > old_md_mtime)
-                    ):
-                        md = cb.to_dict()
-                        md = md.get("comicbox", {})
-                        md["metadata_mtime"] = new_md_mtime
-                    else:
-                        md["page_count"] = cb.get_page_count()
-                else:
-                    md["page_count"] = cb.get_page_count()
-                md["file_type"] = cb.get_file_type()
-            md["path"] = path
+            md = self._extract_path_comicbox(
+                path, old_comic_values, import_metadata=import_metadata
+            )
         except (
             UnsupportedArchiveTypeError,
             BadZipFile,
@@ -86,6 +116,18 @@ class ExtractMetadataImporter(AggregateMetadataImporter):
             self.metadata[FIS].update(failed_import)
         return md
 
+    @staticmethod
+    def _get_all_old_comic_values(all_paths: frozenset[str]):
+        """Get some old comic values."""
+        old_comics = Comic.objects.filter(path__in=all_paths).values(
+            "path", "metadata_mtime", "page_count", "file_type"
+        )
+        old_comic_values = {}
+        for old_comic in old_comics:
+            old_path = old_comic.pop("path")
+            old_comic_values[old_path] = old_comic
+        return MappingProxyType(old_comic_values)
+
     def extract_metadata(self, status=None) -> int:
         """Extract comic metadata into memory."""
         count = 0
@@ -108,11 +150,14 @@ class ExtractMetadataImporter(AggregateMetadataImporter):
 
             # Set import_metadata flag
             import_metadata = self._set_import_metadata_flag()
+            old_comic_values = self._get_all_old_comic_values(all_paths)
 
             for path in all_paths:
                 if self.abort_event.is_set():
                     return count
-                if md := self._extract_path(path, import_metadata=import_metadata):
+                if md := self._extract_path(
+                    path, old_comic_values, import_metadata=import_metadata
+                ):
                     self.metadata[EXTRACTED][path] = md
                 else:
                     self.metadata[SKIPPED].add(path)
