@@ -1,15 +1,17 @@
 """Notification serializers."""
 
-from rest_framework.serializers import CharField, JSONField, Serializer
+from rest_framework.fields import CharField
+from rest_framework.serializers import Serializer
 
 from codex.serializers.browser.settings import BrowserSettingsSerializer
+from codex.serializers.route import RouteSerializer
 
 
 class ReaderRedirectSerializer(Serializer):
     """Reader 404 message."""
 
     reason = CharField(read_only=True)
-    route = JSONField(read_only=True)
+    route = RouteSerializer(read_only=True)
 
 
 class BrowserRedirectSerializer(ReaderRedirectSerializer):
