@@ -1,7 +1,8 @@
 """Whitenoise setup functions."""
+
 import re
 
-IMF_RE = re.compile(r"^.+\.[0-9a-f]{8,12}\..+$")
+IMF_RE = re.compile(r"^.+[.-][0-9a-zA-Z_-]{8,12}\..+$")
 
 
 def immutable_file_test(_path, url):
