@@ -3,10 +3,10 @@
 import asyncio
 import signal
 from asyncio import Event
+from sys import platform
 
-from codex.logger.logging import get_logger
+from loguru import logger
 
-LOG = get_logger(__name__)
 STOP_SIGNAL_NAMES = (
     "SIGABRT",
     "SIGBREAK",
@@ -27,7 +27,7 @@ def _shutdown_signal_handler(*_args):
     """Initiate Codex Shutdown."""
     if SHUTDOWN_EVENT.is_set():
         return
-    LOG.info("Asking hypercorn to shut down gracefully. Could take 10 seconds...")
+    logger.info("Asking hypercorn to shut down gracefully. Could take 10 seconds...")
     SHUTDOWN_EVENT.set()
 
 
@@ -35,7 +35,7 @@ def _restart_signal_handler(*_args):
     """Initiate Codex Restart."""
     if RESTART_EVENT.is_set():
         return
-    LOG.info("Restart signal received.")
+    logger.info("Restart signal received.")
     RESTART_EVENT.set()
     _shutdown_signal_handler()
 
@@ -43,10 +43,14 @@ def _restart_signal_handler(*_args):
 def bind_signals_to_loop():
     """Binds signals to the handlers."""
     try:
-        loop = asyncio.get_running_loop()
+        if platform == "win32":
+            sig_add = signal.signal
+        else:
+            loop = asyncio.get_running_loop()
+            sig_add = loop.add_signal_handler
         for name in STOP_SIGNAL_NAMES:
             if sig := getattr(signal, name, None):
-                loop.add_signal_handler(sig, _shutdown_signal_handler)
-        loop.add_signal_handler(signal.SIGUSR1, _restart_signal_handler)
+                sig_add(sig, _shutdown_signal_handler)
+        sig_add(signal.SIGUSR1, _restart_signal_handler)
     except NotImplementedError:
-        LOG.info("Shutdown and restart signal handling not implemented on windows.")
+        logger.info("Shutdown and restart signal handling not implemented on windows.")
