@@ -1,10 +1,9 @@
 // {% load static %}
-var CACHE_PREFIX = "codex-pwa-v";
-var STATIC_CACHE_NAME = CACHE_PREFIX + new Date().getSeconds();
-var OFFLINE_PATH = "{% static 'pwa/offline.html' %}";
-var FILES_TO_CACHE = [
+const CACHE_PREFIX = "codex-pwa-v";
+const STATIC_CACHE_NAME = CACHE_PREFIX + new Date().getSeconds();
+const OFFLINE_PATH = "{% static 'pwa/offline.html' %}";
+const FILES_TO_CACHE = [
   OFFLINE_PATH,
-  "{% static 'img/logo-32.webp' %}",
   "{% static 'img/logo-maskable-180.webp' %}",
   "{% static 'img/logo-maskable.svg' %}",
   "{% static 'img/logo.svg' %}",
