@@ -1,25 +1,33 @@
-"""Codex URL Configuration.
+"""
+Codex URL Configuration.
 
 https://docs.djangoproject.com/en/dev/topics/http/urls/
 """
 
 from django.contrib.staticfiles.storage import staticfiles_storage
-from django.urls import include, path, register_converter, set_script_prefix
+from django.urls import include, path, register_converter
 from django.views.generic.base import RedirectView
 
-from codex.settings.settings import ROOT_PATH
-from codex.urls.converters import GroupConverter
+from codex.settings import DEBUG
+from codex.urls.converters import GroupConverter, IntListConverter
 
 register_converter(GroupConverter, "group")
+register_converter(IntListConverter, "int_list")
 
-if ROOT_PATH:
-    # Django 5 bug https://code.djangoproject.com/ticket/35169#comment:11
-    set_script_prefix(ROOT_PATH)
 
-urlpatterns = [
+urlpatterns = []
+if DEBUG:
+    # Pyright doesn't follow logic so will try to find these types.
+    from schema_graph.views import Schema  # type: ignore[reportMissingImports]
+
+    urlpatterns += [
+        path("schema/", Schema.as_view()),  # type: ignore[reportPossiblyUnboundVariable]
+    ]
+
+urlpatterns += [
     path(
         "favicon.ico",
-        RedirectView.as_view(url=staticfiles_storage.url("img/logo-32.webp")),
+        RedirectView.as_view(url=staticfiles_storage.url("img/logo.svg")),
         name="favicon",
     ),
     path(
