@@ -3,39 +3,42 @@
 from enum import Enum
 
 from channels.generic.websocket import AsyncWebsocketConsumer
-
-from codex.logger.logging import get_logger
+from loguru import logger
+from typing_extensions import override
 
 ChannelGroups = Enum("ChannelGroups", "ALL ADMIN")
 
-LOG = get_logger(__name__)
-
 
 class NotifierConsumer(AsyncWebsocketConsumer):
     """Base Notifier Consumer."""
 
-    @staticmethod
-    def _get_groups(user):
+    def _get_groups(self) -> list[str]:
         """Dynamic groups by user type."""
         groups = [ChannelGroups.ALL.name]
-        if user.is_staff:
+        user = self.scope.get("user") if self.scope else None
+        user_channel = None
+        if user:
+            user_channel = f"user_{user.id}"
+        else:
+            session = self.scope.get("session")
+            if session:
+                user_channel = f"user_{session.session_key}"
+        if user_channel:
+            groups += [user_channel]
+        if user and user.is_staff:
             groups += [ChannelGroups.ADMIN.name]
         return groups
 
+    @override
     async def websocket_connect(self, message):
         """Authorize with user and connect websocket to groups."""
-        # Authorization
-        user = self.scope.get("user") if self.scope else None
-        if not user:
-            LOG.warning("Websockets not available for unregistered users.")
-            return
-
         # Set groups for user.
-        self.groups = self._get_groups(user)
+        self.groups = self._get_groups()
 
         await super().websocket_connect(message)
-        LOG.debug(f"Websocket connected to {self.groups}")
+        logger.trace(f"Websocket connected to {self.groups}")
 
+    @override
     async def disconnect(self, code):
         """Close channels after WebSocket disconnect."""
         await self.close(code)
@@ -44,6 +47,6 @@ class NotifierConsumer(AsyncWebsocketConsumer):
         """Send message to client."""
         text = event.get("text")
         if not text:
-            LOG.warning("No text in message")
+            logger.warning(f"No text in websockets message: {event}")
             return
         await self.send(text)
